@@ -111,7 +111,6 @@ public:
     string=new Lum::String();
     string->SetMinWidth(Lum::Base::Size::stdCharWidth,Lum::Base::NumberDigits(std::numeric_limits<time_t>::max()));
     string->SetAlignment(Lum::String::right);
-    string->RequestFocus();
     string->SetModel(unixInput);
     label->AddLabel(_(L"UNIX_TIME",L"Unix time:"),string);
 
@@ -136,7 +135,6 @@ public:
 
     button=new Lum::Button();
     button->SetFlex(true,false);
-    button->RequestFocus();
     button->SetType(Lum::Button::typeCommit);
     button->SetModel(convertUnix);
     button->SetText(_(L"CONVERT",L"_Convert"));
@@ -175,7 +173,6 @@ public:
 
     button=new Lum::Button();
     button->SetFlex(true,false);
-    button->RequestFocus();
     button->SetType(Lum::Button::typeCommit);
     button->SetModel(convertLocal);
     button->SetText(_(L"CONVERT",L"_Convert"));
@@ -217,14 +214,12 @@ public:
 
     button=new Lum::Button();
     button->SetFlex(true,false);
-    button->RequestFocus();
     button->SetModel(about);
     button->SetText(_ld(dlgButtonAbout));
     row->AddOptional(button);
 
     button=new Lum::Button();
     button->SetFlex(true,false);
-    button->RequestFocus();
     button->SetModel(GetClosedAction());
     button->SetText(_ld(dlgButtonQuit));
     row->Add(button);
